@@ -122,9 +122,6 @@ class Parser:
                     ]}
                 ]
 
-                helpers.debug('\n[parser.py] __main_parsing() | regions 1 [R]:')
-                print(R)
-
                 for region in R:
                     # Para cada região, busca o símbolo inicial
                     reg = region[list(region.keys())[0]]
@@ -143,9 +140,6 @@ class Parser:
                             Q.enqueue(temp2)
                             Q.enqueue(RelationNode)
 
-                helpers.debug('\n[parser.py] __main_parsing() | regions 2 [R]:')
-                print(R)
-
                 R = [
                     {'super': [
                         [listin[temp1]['xmax'], listin[temp1]['wall']['top']], # left, top
@@ -191,18 +185,18 @@ class Parser:
             s['centroid'] = list(s['centroid'])
             s['checked'] = False
 
-            if s['label'] in ['12', '14', '16']:
+            if s['label'] in ['11', '13', '15']:
                 s['type'] = 'Open'
-            elif s['label'] in ['13', '15', '17']:
+            elif s['label'] in ['12', '14', '16']:
                 s['type'] = 'Close'
             else:
                 s['type'] = 'Normal'
 
-            if re.search("^[0-9]$", str(s['label']) or s['label'] == '20'): # label 20 = b
+            if re.search("^[0-9]$", str(s['label'])) or s['label'] == '19': # label 19 b
                 s['centroid_class'] = 'Ascending'
                 s['centroid'][1] = s['ymin'] + (3/5) * (s['ymax'] - s['ymin'])
                 # s['centroid'][1] = s['ymin'] + (3/4) * (s['ymax'] - s['ymin'])
-            elif s['label'] == '26' or s['type'] == 'Open' or s['label'] == '24':
+            elif s['label'] == '25' or s['type'] == 'Open' or s['label'] == '23': # label 25 y, 23 sqrt 30 =
                 s['centroid_class'] = 'Descending'
                 s['centroid'][1] = s['ymin'] + (1/4) * s['h']
             else:
@@ -225,7 +219,8 @@ class Parser:
 
         helpers.debug('[parser.py] __overlap() | listIndex: %d ' % listIndex)
 
-        if listin[symbolIndex]['label'] == '11':
+        # '-' symbol
+        if listin[symbolIndex]['label'] == '10':
             maxLength = listin[symbolIndex]['xmax'] - listin[symbolIndex]['xmin']
         else:
             maxLength = -1
@@ -242,8 +237,9 @@ class Parser:
 
         while listIndex < n and listin[listIndex]['xmin'] < listin[symbolIndex]['xmax']:
 
+            # symbol '10' '-'
             if not listin[listIndex]['checked'] and \
-                listin[listIndex]['label'] == '11' and \
+                listin[listIndex]['label'] == '10' and \
                 listin[listIndex]['centroid'][1] >= top and \
                 listin[listIndex]['centroid'][1] <= bottom and \
                 listin[listIndex]['xmin'] <= (listin[symbolIndex]['xmin'] + 8) and \
@@ -281,11 +277,6 @@ class Parser:
         while leftmostIndex == -1 and listIndex < n:
             helpers.debug('[parser.py] ... symbol index: %d' % listIndex)
             helpers.debug('[parser.py] ... symbol label: %s' % listin[listIndex]['label'])
-            helpers.debug('[parser.py] ... symbol centroid [R]: ')
-            print(listin[listIndex]['centroid'])
-            helpers.debug('[parser.py] ... symbol rounded centroid [R]: ')
-            print(round(listin[listIndex]['centroid'][0]))
-            print(round(listin[listIndex]['centroid'][1]))
 
             # Adicionei o round()
             # Adicionei o >=, <=,... - era >, <,...
@@ -318,8 +309,8 @@ class Parser:
 
         right = listin[index]['wall']['right']
 
-        # Solve the region with "=", "-", "." label 
-        if int(listin[index]['label']) in [10, 11, 29]:
+        # Solve the region with "-", "." label 
+        if int(listin[index]['label']) in [10, 28]:
             top = listin[index]['wall']['top']
             bottom = listin[index]['wall']['bottom']
         else:
@@ -338,10 +329,12 @@ class Parser:
             )
         )
         helpers.debug('[parser.py] __hor() | top: %d, bottom: %d, left: %d, right: %d' % (top, bottom, left, right))
+        global stop
         stop = False
 
         c = 0
         global a
+        a = -1
 
         for s in range(0, len(listin)):
             c += 1
@@ -351,29 +344,36 @@ class Parser:
                     symbol = listin[s]
 
                     helpers.debug('[parser.py] __hor() | ... symbol: %s' % symbol['label'])
+                    helpers.debug('[parser.py] __hor() | ... symbol centroid: %s ' % symbol['centroid'])
+                    helpers.debug('[parser.py] __hor() | ... symbol coordinates: %s %s %s %s' % (symbol['xmin'], symbol['xmax'], symbol['ymin'], symbol['ymax']))
 
-                    if int(listin[index]['label']) in range(11,18):
+                    # if int(listin[index]['label']) in range(10,17):
+                    # if int(listin[index]['label']) in range(10,16): # vou testar assim
+                    if int(listin[index]['label']) in range(10,17) or int(listin[index]['label']) == 30: # mudei de volta 21/06 22:02 e adicionei o 30
                         helpers.debug('[parser.py] __hor() | ...... before call start (11,18)')
                         R = [[left, top], [right, bottom]]
                         a = self.__start(listin, R)
                         stop = True
                     else: 
                         helpers.debug('[parser.py] __hor() | ...... not(11,18)')
-                        helpers.debug('[parser.py] __hor() | ...... symbol centroid: ')
-                        print(symbol['centroid'])
+
                         # Adicionei o round() nos dois
                         # Adicionei o >=, <=, ... - era só >, <, ...
                         if round(symbol['centroid'][0]) >= round(left) and \
                             round(symbol['centroid'][0]) <= round(right) and \
                             round(symbol['centroid'][1]) <= round(bottom) and \
                             round(symbol['centroid'][1]) >= round(top):
+                                helpers.debug('[parser.py] __hor() | ......... founded: %s' % s)
                                 a = s
                                 stop = True
 
-        if a:
             helpers.debug('[parser.py] __hor() | a: %d ' % a)
-            helpers.debug('[parser.py] __hor() | a label: %s ' % listin[a]['label'])
             helpers.debug('[parser.py] __hor() | stop: %s ' % stop)
+            if stop:
+                break
+
+        if a != -1:
+            helpers.debug('[parser.py] __hor() | a label: %s ' % listin[a]['label'])
 
         if stop and a != -1:
             helpers.debug('[parser.py] __hor() | ... before overlap')
@@ -404,13 +404,13 @@ class Parser:
                 except BaseException as e:
                     print('Exception: ', e)
 
-            if current.node_type == 'RegionNode' or current.data['label'] == '24':
+            if current.node_type == 'RegionNode' or current.data['label'] == '23': # 23 sqrt
                 latex.append('{')
 
             for node in current.children:
                 recur(node)
 
-            if current.node_type == 'RegionNode' or current.data['label'] == '24':
+            if current.node_type == 'RegionNode' or current.data['label'] == '23': # 23 sqrt
                 latex.append('}')
 
         recur(node)
@@ -437,17 +437,6 @@ class Parser:
         E -> S^{S} | S_{S} | \\frac{S}{S} | \sqrt{S} | N | L | e 
         '''
         helpers.debug('[parser.py] __list_to_latex_obj() | tlist: ')
-        teste = []
-        for t in tlist:
-            if not isinstance(t, str):
-                del t['image']
-                teste.append(t['label'])
-            else:
-                teste.append(t)
-            print(t)
-
-        abacate = "".join(teste)
-        print('ABACATE: ', abacate)
 
         latex = []
 
